/*!
 * @file sound_buffer.h
 * @brief Definition of the sound-buffer-class
*/

#ifndef _SOUND_BUFFER_H
#define _SOUND_BUFFER_H

#include "base_object.h"
#include "alincl.h"

#include "sound_buffer_data.h"

namespace OrxSound
{
  //! A class that represents a datastructure to play Sounds.
  class SoundBuffer : public BaseObject
  {
    ObjectListDeclaration(SoundBuffer);
  public:
    SoundBuffer();
    SoundBuffer(const std::string& fileName);

    /** @see SoundBufferData::load */
    inline bool load(const std::string& fileName) { return this->data->load(fileName); };
    /** @see SoundBufferData::loadWav */
    inline bool loadWAV(const std::string& fileName) { return this->data->loadWAV(fileName); };
    /** @see SoundBufferData::loadOgg */
    inline bool loadOGG(const std::string& fileName) { return this->data->loadOGG(fileName); };

    /** @returns the ID of the buffer used in this SoundBuffer */
    inline ALuint getID() const { return this->data->getID(); }

  private:
    SoundBufferData::Pointer    data;
  };
}
#endif /* _SOUND_BUFFER_H */
